@@ -46,7 +46,7 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.6.1"
+VERSION = "0.6.2"
 LOCK_SH = 0
 LOCK_EX = 1
 CACHE_SOCKET = "/tmp/cache.starrydb"
@@ -204,7 +204,7 @@ class StarryServer(object):
 
                 self.cache = None
 
-        if type(self.address) is str:
+        if pathlib.Path(str(self.address)).is_socket():
             try:
                 os.remove(self.address)
             except:
@@ -232,7 +232,7 @@ class StarryServer(object):
             except:
                 pass
 
-        if type(self.address) is str:
+        if pathlib.Path(str(self.address)).is_socket():
             try:
                 os.remove(self.address)
             except:
